Applications
============

Vumi applications implement application logic or call out to
external services that implement such logic. Usually you will
implement your own application workers but Vumi does provide a base
application worker class and a few generic application workers.

.. toctree::
    :maxdepth: 1

    base.rst
    http_relay.rst
    rapidsms_relay.rst
    sandbox.rst
